// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PLASMA_VERSION_H
#define PLASMA_VERSION_H

#define PLASMA_VERSION_STRING "6.6.2"
#define PLASMA_VERSION_MAJOR 6
#define PLASMA_VERSION_MINOR 6
#define PLASMA_VERSION_PATCH 2
#define PLASMA_VERSION ((6<<16)|(6<<8)|(2))

#endif
